@@ -38,12 +38,11 @@
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KRecentFilesAction>
-#include <KService>
 #include <KSharedConfig>
 #include <KConfigDialog>
-#include <KConfigGroup>
-#include <KConfigSkeleton>
 #include <KXMLGUIFactory>
+#include <KPluginLoader>
+#include <KConfigSkeleton>
 
 #include <QApplication>
 #include <QDragEnterEvent>
@@ -51,7 +50,6 @@
 #include <QFileDialog>
 #include <QMimeData>
 #include <QPointer>
-#include <QRegularExpression>
 #include <QStatusBar>
 
 static bool isValidArchiveDrag(const QMimeData *data)
@@ -246,7 +244,8 @@ void MainWindow::setShowExtractDialog(bool option)
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     // Preview windows don't have a parent, so we need to manually close them.
-    foreach (QWidget *widget, qApp->topLevelWidgets()) {
+    const auto topLevelWidgets = qApp->topLevelWidgets();
+    for (QWidget *widget : topLevelWidgets) {
         if (widget->isVisible()) {
             widget->close();
         }
@@ -271,7 +270,8 @@ void MainWindow::showSettings()
 
     auto dialog = new Kerfuffle::SettingsDialog(this, QStringLiteral("settings"), iface->config());
 
-    foreach (Kerfuffle::SettingsPage *page, iface->settingsPages(this)) {
+    const auto pages = iface->settingsPages(this);
+    for (Kerfuffle::SettingsPage *page : pages) {
         dialog->addPage(page, page->name(), page->iconName());
         connect(dialog, &KConfigDialog::settingsChanged, page, &Kerfuffle::SettingsPage::slotSettingsChanged);
         connect(dialog, &Kerfuffle::SettingsDialog::defaultsButtonClicked, page, &Kerfuffle::SettingsPage::slotDefaultsButtonClicked);
