@@ -482,11 +482,12 @@ void ExtractTest::testPreservePermissions_data()
     QTest::addColumn<int>("expectedPermissions");
 
     // Repeat the same test case for each format and for each plugin supporting the format.
-    foreach (const QString &format, TestHelper::testFormats()) {
+    const QStringList formats = TestHelper::testFormats();
+    for (const QString &format : formats) {
         const QString filename = QFINDTESTDATA(QStringLiteral("data/test_permissions.%1").arg(format));
         const auto mime = QMimeDatabase().mimeTypeForFile(filename, QMimeDatabase::MatchExtension);
         const auto plugins = m_pluginManager.preferredWritePluginsFor(mime);
-        foreach (const auto plugin, plugins) {
+        for (const auto plugin : plugins) {
             QTest::newRow(QStringLiteral("test preserve 0755 permissions (%1, %2)").arg(format, plugin->metaData().pluginId()).toUtf8().constData())
                 << filename
                 << plugin
