@@ -32,8 +32,9 @@
 
 #include <KLocalizedString>
 
-#include <QDirIterator>
 #include <QThread>
+#include <QFileInfo>
+#include <QDir>
 
 #include <archive_entry.h>
 
@@ -53,7 +54,7 @@ LibarchivePlugin::LibarchivePlugin(QObject *parent, const QVariantList &args)
 
 LibarchivePlugin::~LibarchivePlugin()
 {
-    foreach (const auto e, m_emittedEntries) {
+    for (const auto e : qAsConst(m_emittedEntries)) {
         // Entries might be passed to pending slots, so we just schedule their deletion.
         e->deleteLater();
     }
@@ -158,7 +159,7 @@ bool LibarchivePlugin::hasBatchExtractionProgress() const
 
 bool LibarchivePlugin::doKill()
 {
-    return true;
+    return false;
 }
 
 bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options)
